@@ -8,9 +8,15 @@
  */
 
 char RCSid_simpleEvent [] =
-  "$Header: /a/src3/tcl7.1/tclTCP1.1/RCS/simpleEvent.c,v 1.1 1992/10/28 18:51:36 vanandel Exp vanandel $";
-/* $Source: /a/src3/tcl7.1/tclTCP1.1/RCS/simpleEvent.c,v $
+  "$Header: /net/src3/btcl/tclTCP2.1/src/RCS/simpleEvent.c,v 1.2 1994/08/04 13:31:26 vanandel Exp $";
+/* $Source: /net/src3/btcl/tclTCP2.1/src/RCS/simpleEvent.c,v $
  * $Log: simpleEvent.c,v $
+ * Revision 1.2  1994/08/04  13:31:26  vanandel
+ * change to allow sharing source with VxWorks version
+ *
+ * Revision 1.1  1994/03/09  18:46:39  vanandel
+ * Initial revision
+ *
  * Revision 1.1  1992/10/28  18:51:36  vanandel
  * Initial revision
  *
@@ -34,6 +40,23 @@ char RCSid_simpleEvent [] =
 #include <tclInt.h>
 #include <tclUnix.h>
 
+#ifdef TCL_VW
+#include <vxWorks.h>
+#include <systime.h>
+#include <errnoLib.h>
+#include <taskVarLib.h>
+#include <logLib.h>
+#include <string.h>
+#include <selectLib.h>
+#define TASK(t) Tcl_ctxt->t
+#else
+#define TASK(t) t
+
+#endif
+
+#include "tcl.h"
+
+
 #ifdef USE_TK
 #include <tk.h>
 #endif
@@ -127,8 +150,10 @@ typedef struct simple_FileHandler {
  * point:
  */
 
+#ifndef TCL_VW
 static Simple_FileHandler * simpleFirstFileHandler
   = (Simple_FileHandler *) NULL;
+#endif
 
 #endif /* neither USE_TK nor USE_XT */
 
@@ -278,7 +303,7 @@ Error in bgerror:\n\
 
   Tcl_ResetResult (interp);
 
-  free (command);
+  ckfree (command);
 
   ckfree (error);
 
@@ -317,13 +342,13 @@ simpleDoWhenIdle (proc, clientData)
   handler -> proc = proc;
   handler -> clientData = clientData;
   handler -> next = (Simple_IdleHandler *) NULL;
-  handler -> prev = simpleLastIdleHandler;
+  handler -> prev = TASK(simpleLastIdleHandler);
   if (handler -> prev == NULL) {
-    simpleFirstIdleHandler = handler;
+    TASK(simpleFirstIdleHandler) = handler;
   } else {
     handler -> prev -> next = handler;
   }
-  simpleLastIdleHandler = handler;
+  TASK(simpleLastIdleHandler) = handler;
 
 #endif
 
@@ -373,7 +398,8 @@ simpleCancelIdleCall (proc, clientData)
   Simple_IdleHandler * h;
   Simple_IdleHandler * nexth;
 
-  for (h = simpleFirstIdleHandler;
+  for (h = TASK(simpleFirstIdleHandler);
+
        h != (Simple_IdleHandler *) NULL;
        h = nexth)
     {
@@ -491,7 +517,7 @@ simpleProcessIdleCalls (flags)
   Simple_IdleProc * proc;
   ClientData clientData;
 
-  for (h = simpleFirstIdleHandler;
+  for (h = TASK(simpleFirstIdleHandler);
        h != (Simple_IdleHandler *) NULL;
        h = nexth)
     {
@@ -507,7 +533,7 @@ simpleProcessIdleCalls (flags)
 	clientData = h -> clientData;
 	simpleDeleteIdleHandler (h);
 	(*proc) (clientData);
-	nexth = simpleFirstIdleHandler;
+	nexth = TASK(simpleFirstIdleHandler);
 
       } else {
 
@@ -535,13 +561,13 @@ simpleDeleteIdleHandler (h)
      Simple_IdleHandler * h;
 {
   if (h -> prev == NULL) {
-    simpleFirstIdleHandler = h -> next;
+    TASK(simpleFirstIdleHandler) = h -> next;
   } else {
     h -> prev -> next = h -> next;
   }
 
   if (h -> next == NULL) {
-    simpleLastIdleHandler = h -> prev;
+    TASK(simpleLastIdleHandler) = h -> prev;
   } else {
     h -> next -> prev = h -> prev;
   }
@@ -642,14 +668,14 @@ simpleCreateFileHandler (fd, mask, proc, clientData)
 
   /* Find an existing handler for the same file, or create a new one */
 
-  for (h = simpleFirstFileHandler; h; h = h -> next) {
+  for (h = TASK(simpleFirstFileHandler); h; h = h -> next) {
     if (h -> fd == fd) break;
   }
   if (!h) {
     h = (Simple_FileHandler *) ckalloc (sizeof (Simple_FileHandler));
     h -> fd = fd;
-    h -> next = simpleFirstFileHandler;
-    simpleFirstFileHandler = h;
+    h -> next = TASK(simpleFirstFileHandler);
+    TASK(simpleFirstFileHandler) = h;
     if (h -> next) {
       h -> next -> prev = h;
     }
@@ -757,7 +783,7 @@ simpleDeleteFileHandler (fd)
 
   Simple_FileHandler * h;
 
-  for (h = simpleFirstFileHandler; h != NULL; h = h -> next) {
+  for (h = TASK(simpleFirstFileHandler); h != NULL; h = h -> next) {
 
     if (h -> fd == fd) {
       h -> mask |= SIMPLE_DELETE;
@@ -829,7 +855,7 @@ simpleFileSelect (flags)
 
     /* First off, destroy any file handlers that are marked for deletion. */
 
-    for (h = simpleFirstFileHandler; h != NULL; h = nexth) {
+    for (h = TASK(simpleFirstFileHandler); h != NULL; h = nexth) {
       nexth = h -> next;
 
       if (h -> mask & SIMPLE_DELETE) {
@@ -837,7 +863,7 @@ simpleFileSelect (flags)
 	if (h -> prev != NULL) {
 	  h -> prev -> next = nexth;
 	} else {
-	  simpleFirstFileHandler = nexth;
+	  TASK(simpleFirstFileHandler) = nexth;
 	}
 	if (nexth != NULL) {
 	  nexth -> prev = h -> prev;
@@ -850,7 +876,7 @@ simpleFileSelect (flags)
     /* Return a negative number when all handlers have been destroyed */
 
     errno = 0;
-    if (simpleFirstFileHandler == NULL) return -1;
+    if (TASK(simpleFirstFileHandler) == NULL) return -1;
   
     /* Set up the select() masks */
 
@@ -859,7 +885,7 @@ simpleFileSelect (flags)
     FD_ZERO( &writefds );
     FD_ZERO( &exceptfds );
 
-    for (h = simpleFirstFileHandler; h != NULL; h = nexth) {
+    for (h = TASK(simpleFirstFileHandler); h != NULL; h = nexth) {
       nexth = h -> next;
       if ((h -> mask & SIMPLE_DELETE) == 0) {
 	fd = h -> fd;
@@ -893,7 +919,7 @@ simpleFileSelect (flags)
       /* fired.  Note that invoking a handler might delete */
       /* it, or delete another, so we have to check for liveness. */
       
-      for (h = simpleFirstFileHandler; h != NULL; h = nexth) {
+      for (h = TASK(simpleFirstFileHandler); h != NULL; h = nexth) {
 	nexth = h -> next;
 	if ((h -> mask & SIMPLE_DELETE) == 0) {
 	  mask = 0;
